@@ -2,7 +2,7 @@
 """
 Created on Sat Sep 11 20:12:14 2021
 
-@author: Eli Shamis
+@author: NeuroBrave
 """
 
 from neurospeed.utils.http_service import HttpService
@@ -29,10 +29,10 @@ class Gateway_HttpHandler:
 
     def get_connections(self, pager, filters): 
          endpoint = "/gateway/connections"
-         filters = json.dumps({"filters": filters, "pager": pager})
+         request = json.dumps({"filters": filters, "pager": pager})
          headers_copy = copy.deepcopy(self._headers)
          headers_copy["content-type"] = "application/json"
-         response = self._http_service.POST_request(endpoint, filters, headers_copy)
+         response = self._http_service.POST_request(endpoint, request, headers_copy)
          return response
      
         
