@@ -47,6 +47,12 @@ class HIA_Client:
                 
         self._sio = socketio.Client(logger=logger_on, engineio_logger=False, reconnection_delay  = 5, reconnection = True) 
 
+        self._current_experiment_labels = ["none"]
+        self._current_experiment_onetime_labels = ["none"]
+
+    def set_label(self, label):
+        self._current_experiment_labels = [label]
+
         
     # Socket data sender - Start 
     def send_data(self, data, stream_id):  
@@ -77,6 +83,10 @@ class HIA_Client:
             if (packet_ready):       
               #  print("{} user_data packet ready for stream_id: {} ".format(self._contex, stream_id))
                 packet_payload = {"stream_id": stream_id, "device_type": self._device_type, "hia_id": self._hia_id, "data": json.dumps(TX_buffer)}
+                packet_payload["experiment"] = {
+                                "packet_labels": self._current_experiment_labels,
+                                "onetime_labels": self._current_experiment_onetime_labels
+                            } 
                 self._sio.emit(self._packet_endpoint, packet_payload)      
                 packet_ready = False
      # Socket data sender - End      
